Product class abstract

Available extensions

Constructors

Product([dynamic updates(ProductBuilder b)])
factory

Properties

currencyCode → String
no setter
currencySymbol → String
no setter
description → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
price → String
no setter
purchaseDetails → BuiltList<PurchaseDetail>
no setter
rawPrice → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setter

Methods

isValid() → bool

Available on Product, provided by the ExtProduct extension

isValidString() → String

Available on Product, provided by the ExtProduct extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ProductBuilder b)) → Product
Rebuilds the instance.
inherited
toBuilder() → ProductBuilder
Converts the instance to a builder B.
inherited
toJson() → String
toProductDetail() → dynamic

Available on Product, provided by the ExtProduct extension

toString() → String
A string representation of this object.
inherited
validColor() → Color

Available on Product, provided by the ExtProduct extension

validPurchaseDetail() → PurchaseDetail?

Available on Product, provided by the ExtProduct extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Product>
no setter

Static Methods

fromJson(String jsonString) → Product?