PurchaseDetail class abstract

Available extensions

Constructors

PurchaseDetail([dynamic updates(PurchaseDetailBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
productID → String
no setter
purchaseID → String?
no setter
receipt → AppStoreReceiptValidationResult?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
no setter
transactionDate → String?
no setter
valid → bool?
no setter

Methods

isValid() → bool

Available on PurchaseDetail, provided by the ExtPurchaseDetails extension

isValidInt() → int

Available on PurchaseDetail, provided by the ExtPurchaseDetails extension

isValidString() → String

Available on PurchaseDetail, provided by the ExtPurchaseDetails extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PurchaseDetailBuilder b)) → PurchaseDetail
Rebuilds the instance.
inherited
toBuilder() → PurchaseDetailBuilder
Converts the instance to a builder B.
inherited
toJson() → String
toPurchaseDetailEntity() → PurchaseDetail

Available on PurchaseDetail, provided by the ExtPurchaseDetails extension

toString() → String
A string representation of this object.
inherited
validColor() → Color

Available on PurchaseDetail, provided by the ExtPurchaseDetails extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PurchaseDetail>
no setter

Static Methods

fromJson(String jsonString) → PurchaseDetail?